from __future__ import absolute_import
from __future__ import division
from __future__ import print_function
from __future__ import unicode_literals

# The version is an incrementing number, if the version changes it means
# one of the parser components has changed and may produce different
# results for a given parsable input.
# This should be updated manually when a parser component changes, note
# that this includes changes to any module under checkbox.parsers.
__version__ = '3'
